@@ -29,6 +29,7 @@ import openstack
 
 from tripleo_common import exception
 from tripleo_common import constants
+from tripleo_common import inventories
 
 HOST_NETWORK = 'ctlplane'
 DEFAULT_DOMAIN = 'localdomain.'
@@ -271,7 +272,7 @@ class TripleoInventory(object):
         self.host_network = host_network or HOST_NETWORK
         self.ansible_ssh_user = ansible_ssh_user
         self.undercloud_key_file = undercloud_key_file
-        self.plan_name = plan_name
+        self.plan_name = self.plan_group_name = plan_name
         self.ansible_python_interpreter = ansible_python_interpreter
         self.hostvars = {}
         self.undercloud_connection = undercloud_connection
@@ -416,8 +417,8 @@ class TripleoInventory(object):
                 ret[role_name]['hosts'] = hosts_format
 
         if children:
-            allovercloud = ret.setdefault('allovercloud', {})
-            overcloud_vars = allovercloud.setdefault('vars', {})
+            plan_group = ret.setdefault(self.plan_name, {})
+            overcloud_vars = plan_group.setdefault('vars', {})
 
             for vip_name, vip in vip_map.items():
                 if vip and (vip_name in networks or vip_name == 'redis'):
@@ -427,24 +428,14 @@ class TripleoInventory(object):
                 'container_cli', self.get_overcloud_environment().get(
                     'parameter_defaults', {}).get('ContainerCli'))
 
-            allovercloud.setdefault('children', self._hosts(sorted(children),
-                                                            dynamic))
+            plan_group.setdefault(
+                'children', self._hosts(sorted(children), dynamic)
+            )
 
             ret.setdefault(
-                self.plan_name, {'children': self._hosts(['allovercloud'],
-                                                         dynamic)})
-
-            if self.plan_name != 'overcloud':
-                ret.setdefault(
-                    'overcloud',
-                    {
-                        'children': self._hosts(
-                            [
-                                'allovercloud'
-                            ],
-                            dynamic
-                        )
-                    }
+                'allovercloud', {
+                    'children': self._hosts([self.plan_name], dynamic)
+                }
                 )
 
         # Associate services with roles
@@ -648,9 +639,16 @@ class TripleoInventory(object):
                 ret[role_name]['hosts'] = hosts_format
 
         if children:
-            allovercloud = ret.setdefault('allovercloud', {})
-            allovercloud.setdefault('children',
-                                    self._hosts(sorted(children), dynamic))
+            ret.setdefault(
+                self.plan_name, {
+                    'children': self._hosts(sorted(children), dynamic)
+                }
+            )
+            ret.setdefault(
+                'allovercloud', {
+                    'children': self._hosts([self.plan_name], dynamic)
+                }
+            )
 
     def _extend_inventory(self, ret, dynamic, data=None):
         if not data:
@@ -830,16 +828,19 @@ def generate_tripleo_ansible_inventory(heat=None,
 
     inventory_path = os.path.join(
         work_dir, 'tripleo-ansible-inventory.yaml')
-    inv = TripleoInventory(
-        cloud_name=cloud_name,
-        hclient=heat,
-        session=session,
-        ansible_ssh_user=ansible_ssh_user,
-        undercloud_key_file=undercloud_key_file,
-        ansible_python_interpreter=ansible_python_interpreter,
-        plan_name=plan,
-        host_network=ssh_network,
-        work_dir=work_dir)
+    inv = inventories.TripleoInventories({
+        plan: TripleoInventory(
+            cloud_name=cloud_name,
+            hclient=heat,
+            session=session,
+            ansible_ssh_user=ansible_ssh_user,
+            undercloud_key_file=undercloud_key_file,
+            ansible_python_interpreter=ansible_python_interpreter,
+            plan_name=plan,
+            host_network=ssh_network,
+            work_dir=work_dir
+        )
+    })
 
     inv.write_static_inventory(inventory_path)
     return inventory_path
